=========================
Medical Images Dataloader
=========================


.. image:: https://img.shields.io/pypi/v/med_dataloader.svg
        :target: https://pypi.python.org/pypi/med_dataloader


.. image:: https://img.shields.io/travis/com/mrossi93/med_dataloader?branch=master
        :target: https://travis-ci.com/mrossi93/med_dataloader
        

.. image:: https://readthedocs.org/projects/med-dataloader/badge/?version=latest
        :target: https://med-dataloader.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/mrossi93/med_dataloader/shield.svg
     :target: https://pyup.io/repos/github/mrossi93/med_dataloader/
     :alt: Updates



A general-purpose Dataloader for Tensorflow 2.x. It supports many medical image formats.


* Free software: MIT license
* Documentation: https://med-dataloader.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
